@@ -140,7 +140,7 @@ s
     logging.info("NA in final dataframe:")
     logging.info(f"{nna}")
 
-    return df_leads_clean, imp
+    return df_leads_clean, imp , mapping_dicts
 
 
 def preprocessing_predictions(df, imputer, mapping_dicts, config):
